##  Tags v/s Custom Attributes
Knowing when to use tags versus custom attributes ensures data is organized efficiently and meaningfully. Both tags and custom fields should be used judiciously to ensure they add meaningful value and justify the effort required to maintain them.
When managing fact sheets, use tags for temporary statuses and broad categorizations, especially for important attributes with a limited number of classifications that may frequently change. Avoid tags if the information can be adequately modeled using SAP LeanIX's meta-model or if adding more tags would lead to excessive complexity.
Custom attributes are ideal for capturing specific details not covered by the meta-model, especially when various data types are required beyond a simple value list or for information relevant only to certain stakeholders. They are also beneficial for controlling access to specific users.
For a more detailed guide on when to use tags and custom attributes, see [Using Tags and Custom Fields](https://help.sap.com/docs/leanix/ea/tags-and-custom-fields?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to effectively use tags and custom fields in SAP LeanIX.").
